pub struct MuseExecBuilder { /* private fields */ }Expand description
Builder for one muse exec --json invocation.
Implementations
Sourceimpl MuseExecBuilder
impl MuseExecBuilder
pub fn new(prompt: impl Into<String>) -> Self
Sourcepub fn binary(self, path: impl Into<String>) -> Self
pub fn binary(self, path: impl Into<String>) -> Self
Use a specific binary instead of muse from PATH.
pub fn provider(self, provider: Provider) -> Self
Sourcepub fn preset(self, preset: impl Into<String>) -> Self
pub fn preset(self, preset: impl Into<String>) -> Self
Built-in preset (native-basic, miniswe).
pub fn model(self, model: impl Into<String>) -> Self
Sourcepub fn reasoning_effort(self, effort: impl Into<String>) -> Self
pub fn reasoning_effort(self, effort: impl Into<String>) -> Self
Meta reasoning effort (none|minimal|low|medium|high|xhigh|ultra).
Not supported with Provider::Echo.
pub fn base_url(self, url: impl Into<String>) -> Self
pub fn working_directory(self, dir: impl Into<PathBuf>) -> Self
pub fn env(self, key: impl Into<String>, value: impl Into<String>) -> Self
Sourcepub fn build_command(&self) -> Result<Command>
pub fn build_command(&self) -> Result<Command>
Resolve the binary and assemble the command with piped stdio.